@@ -11,16 +11,16 @@ mod disambiguation;
 mod grammar_builder;
 mod grammar_rule;
 mod production;
-mod symbol;
 
 pub use associativity::Associativity;
 pub use disambiguation::Disambiguation;
 pub use grammar_builder::GrammarBuilder;
 pub use grammar_rule::GrammarRule;
 pub use production::Production;
+pub use production::ProductionAction;
+pub use production::ProductionKind;
 use std::collections::HashMap;
 use std::rc::Rc;
-pub use symbol::Symbol;
 
 pub(crate) const START_RULE_NAME: &str = "Γ";
 
@@ -29,14 +29,13 @@ pub(crate) const START_RULE_NAME: &str = "Γ";
 /// [Grammar] is exposed so you can use its type and traits
 /// but normally you create a [Grammar]
 /// by using a [GrammarBuilder](crate::grammar::GrammarBuilder).
-#[derive(Clone)]
-pub struct Grammar {
-    pub(crate) rules: HashMap<Rc<String>, GrammarRule>,
+pub struct Grammar<Value> {
+    /// Internal representation of the rules of this [Grammar].
+    pub rules: HashMap<Rc<String>, GrammarRule<Value>>,
 }
 
-impl Grammar {
-    /// Return the rules of this [Grammar].
-    pub fn rules(&self) -> &HashMap<Rc<String>, GrammarRule> {
-        &self.rules
+impl<Value> std::clone::Clone for Grammar<Value> {
+    fn clone(&self) -> Grammar<Value> {
+        Grammar { rules: self.rules.clone() }
     }
 }
